2025-07-03 Version: 1.10.2
- Generated python 2022-01-01 for quickbi-public.

2025-07-02 Version: 1.10.1
- Update API QueryAuditLog: add request parameters AccessSourceFlag.
- Update API QueryAuditLog: add request parameters UserAccessDevice.


2025-05-28 Version: 1.10.0
- Support API DataInterpretation.
- Update API QueryDatasetInfo: add response parameters Body.Result.DimensionList.$.ExpressionV2.
- Update API QueryDatasetInfo: add response parameters Body.Result.MeasureList.$.ExpressionV2.
- Update API SmartqAuthorize: add request parameters CubeIds.
- Update API SmartqQueryAbility: add response parameters Body.Result.MetaType.$.Type.


2025-04-14 Version: 1.9.2
- Update API SmartqQueryAbility: add response parameters Body.Result.ConclusionText.
- Update API SmartqQueryAbility: add response parameters Body.Result.LogicSql.


2025-03-14 Version: 1.9.1
- Update API AddUser: update param AccountName.
- Update API ListWorkspaceRoleUsers: update param WorkspaceId.
- Update API QueryUserList: update response param.
- Update API UpdateWorkspaceUserRole: update param RoleId.


2024-12-30 Version: 1.9.0
- Support API GetDataSourceConnectionInfo.
- Support API ListDataSource.
- Support API QueryDatasetSmartqStatus.
- Support API QueryLlmCubeWithThemeListByUserId.
- Support API QuerySmartqPermissionByCubeId.
- Support API SmartqAuthTransfer.
- Support API SmartqAuthorize.
- Update API AddUser: update param AccountId.
- Update API QueryApprovalInfo: update param Status.
- Update API QueryAuditLog: update response param.
- Update API QueryWorksBloodRelationship: update response param.
- Update API UpdateWorkspaceUserRole: add param RoleIds.
- Update API UpdateWorkspaceUserRole: update param RoleId.


2024-11-26 Version: 1.8.0
- Support API GetMailTaskStatus.
- Support API GetWorksEmbedList.
- Support API ManualRunMailTask.
- Support API SmartqQueryAbility.
- Update API AddUser: add param AccountId.


2024-10-10 Version: 1.7.0
- Support API GetMailTaskStatus.
- Support API GetWorksEmbedList.
- Support API ManualRunMailTask.


2024-09-18 Version: 1.6.1
- Update API AddUserGroupMember: update response param.
- Update API AddUserGroupMembers: update response param.
- Update API QueryDatasetInfo: update response param.


2024-08-07 Version: 1.6.0
- Support API ModifyCopilotEmbedConfig.
- Support API QueryCopilotEmbedConfig.
- Support API QueryData.
- Support API QueryDataRange.


2024-06-28 Version: 1.5.1
- Update API DataSourceBlood: update response param.


2024-06-27 Version: 1.5.0
- Support API DataSetBlood.
- Support API DataSourceBlood.
- Support API QueryApprovalInfo.
- Support API QueryAuditLog.
- Support API QueryDataServiceList.
- Update API QueryUserList: update response param.
- Update API QueryWorks: update response param.
- Update API QueryWorksByOrganization: update response param.
- Update API QueryWorksByWorkspace: update response param.
- Update API UpdateUser: add param IsDeleted.


2024-05-22 Version: 1.4.0
- Support API CreateTicket4Copilot.
- Support API ListOrganizationRoleUsers.
- Support API ListOrganizationRoles.
- Support API ListWorkspaceRoleUsers.
- Support API ListWorkspaceRoles.
- Support API QueryOrganizationRoleConfig.
- Support API QueryWorkspaceRoleConfig.
- Update API ListFavoriteReports: update response param.
- Update API QueryDatasetInfo: update response param.
- Update API QueryDatasetList: update response param.


2024-05-21 Version: 1.3.0
- Support API ListOrganizationRoleUsers.
- Support API ListOrganizationRoles.
- Support API ListWorkspaceRoleUsers.
- Support API ListWorkspaceRoles.
- Support API QueryOrganizationRoleConfig.
- Support API QueryWorkspaceRoleConfig.
- Update API ListFavoriteReports: update response param.


2024-03-19 Version: 1.2.0
- Support API ListOrganizationRoleUsers.
- Support API ListOrganizationRoles.
- Support API ListWorkspaceRoleUsers.
- Support API ListWorkspaceRoles.
- Support API QueryOrganizationRoleConfig.
- Support API QueryWorkspaceRoleConfig.


2024-03-19 Version: 1.1.9
- Update API AddUser: add param AuthAdminUser.
- Update API AddUser: add param RoleIds.
- Update API AddUser: update param AdminUser.
- Update API AddUser: update param AuthAdminUser.
- Update API AddUser: update response param.
- Update API QueryUserInfoByAccount: add param ParentAccountName.
- Update API QueryUserInfoByAccount: update response param.
- Update API QueryUserInfoByUserId: update response param.
- Update API QueryUserList: update response param.
- Update API UpdateUser: add param RoleIds.


2024-02-27 Version: 1.1.8
- Update API AddUser: add param AuthAdminUser.
- Update API AddUser: add param RoleIds.
- Update API AddUser: update param AdminUser.
- Update API AddUser: update param AuthAdminUser.
- Update API AddUser: update response param.
- Update API QueryUserInfoByAccount: add param ParentAccountName.
- Update API QueryUserInfoByAccount: update response param.
- Update API QueryUserInfoByUserId: update response param.
- Update API QueryUserList: update response param.
- Update API UpdateUser: add param RoleIds.


2023-10-24 Version: 1.1.7
- Generated python 2022-01-01 for quickbi-public.

2023-06-28 Version: 1.1.6
- Add QueryCubePerformance, QueryComponentPerformance, QueryCubeOptimization, and QueryReportPerformance APIs.
- Update error code description.

2023-05-11 Version: 1.1.5
- Add AllotDatasetAccelerationTask API.
- Update error code description.

2022-09-08 Version: 1.1.4
- Add API BatchAddFeishuUsers.

2022-09-08 Version: 1.1.3
- Update API Error Code And Some Parameters Checks.
- Update API CreateTicket QPS.

2022-07-04 Version: 1.1.2
- Add API QueryEmbeddedStaus.

2022-07-04 Version: 1.1.1
- Update API error code.
- Adjust parameters verification rules for some APIs.

2022-03-14 Version: 1.1.0
- Add ResultCallback.

2022-03-10 Version: 1.0.0
- Iinit region api.

